@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# (c) Copyright IBM Corp. 2010, 2018. All Rights Reserved.
+# (c) Copyright IBM Corp. 2010, 2023. All Rights Reserved.
+# pragma pylint: disable=line-too-long
 
 """Action Module server
 
@@ -14,48 +15,29 @@ from __future__ import print_function
 
 import logging
 from logging.handlers import RotatingFileHandler
-from six import string_types
-import re
 import os
 import filelock
 from circuits import Manager, BaseComponent, Component, Debugger, Loader
 from resilient import get_config_file
 from resilient import constants as resilient_constants
 from resilient_circuits import constants, helpers
+from resilient_circuits.actions_component import Actions, ResilientComponent
 from resilient_circuits.app_argument_parser import AppArgumentParser
 from resilient_circuits.component_loader import ComponentLoader
-from resilient_circuits.actions_component import Actions, ResilientComponent
-
+from resilient_circuits.filters import RedactingFilter
 
 application = None
 logging_initialized = False
 
 
-class RedactingFilter(logging.Filter):
-    """ Redacting logging filter to prevent Resilient circuits sensitive password values from being logged.
-
-    """
-    def __init__(self):
-        super(RedactingFilter, self).__init__()
-
-    def filter(self, record):
-        # Best effort regex filter pattern to redact password logging.
-        if isinstance(record.msg, string_types):
-            for p in constants.PASSWD_PATTERNS:
-                if p in record.msg.lower():
-                    regex = r"{0}(?=.*?':\s)(None,|.+?,|.+?'}})".format(p)
-                    record.msg = re.sub(regex, r"***", record.msg)
-
-        return True
-
 
 # Main component for our application
 class App(Component):
     """Our main app component, which sets up the Resilient services and other components"""
 
-    FILE_LOG_FORMAT = '%(asctime)s %(levelname)s [%(module)s] %(message)s'
+    FILE_LOG_FORMAT = '%(asctime)s %(levelname)s [%(module)s] [%(threadName)s] %(message)s'
     SYSLOG_LOG_FORMAT = '%(module)s: %(levelname)s %(message)s'
-    STDERR_LOG_FORMAT = '%(asctime)s %(levelname)s [%(module)s] %(message)s'
+    STDERR_LOG_FORMAT = '%(asctime)s %(levelname)s [%(module)s] [%(threadName)s] %(message)s'
 
     def __init__(self, auto_load_components=True, config_file=None, ALLOW_UNRECOGNIZED=False, IS_SELFTEST=False):
         super(App, self).__init__()
@@ -72,7 +54,7 @@ class App(Component):
     def do_initialization(self):
         self.opts = helpers.get_configs(path_config_file=self.config_file, ALLOW_UNRECOGNIZED=self.ALLOW_UNRECOGNIZED)
 
-        self.config_logging(self.opts["logdir"], self.opts["loglevel"], self.opts['logfile'])
+        self.config_logging(self.opts["logdir"], self.opts["loglevel"], self.opts["logfile"], self.opts[constants.APP_CONFIG_LOG_MAX_BYTES], self.opts[constants.APP_CONFIG_LOG_BACKUP_COUNT])
         LOG.info("Configuration file: %s", self.config_file)
         LOG.info("Resilient server: %s", self.opts.get("host"))
         if self.opts.get("email", None):
@@ -84,6 +66,7 @@ class App(Component):
                         "api key settings.")
         LOG.info("Resilient org: %s", self.opts.get("org"))
         LOG.info("Logging Level: %s", self.opts.get("loglevel"))
+        LOG.info("App Config plugin: %s", self.opts.pam_plugin.__class__.__name__ if self.opts.pam_plugin else "None")
         if self.opts.get("test_actions", False):
             # Make all components aware that we are in test mode
             ResilientComponent.test_mode = True
@@ -91,6 +74,9 @@ class App(Component):
         # Make all components aware that we are in selftest mode
         ResilientComponent.IS_SELFTEST = self.IS_SELFTEST
 
+        # any additional queues to subscribe to as received by IBM SOAR /connectors/queues endpoint
+        connector_queue_names = []
+
         # Connect to events from Action Module.
         # Note: this must be done before components are loaded, because it uses
         # each component's "channel" to initiate subscription to the message queue.
@@ -103,6 +89,7 @@ class App(Component):
             self.action_component = loader.load(filename)
         else:
             self.action_component = Actions(self.opts)
+            connector_queue_names = self.action_component.get_connector_queues()
         self.action_component.register(self)
 
         # Register a `loader` to dynamically load
@@ -111,13 +98,13 @@ class App(Component):
             LOG.info("Components auto-load directory: %s",
                      self.opts["componentsdir"] or "(none)")
             if not self.component_loader:
-                self.component_loader = ComponentLoader(self.opts)
+                self.component_loader = ComponentLoader(self.opts, connector_queue_names)
             else:
                 LOG.info("Updating and re-registering ComponentLoader")
                 self.component_loader.opts = self.opts
             self.component_loader.register(self)
 
-    def config_logging(self, logdir, loglevel, logfile):
+    def config_logging(self, logdir, loglevel, logfile, log_max_bytes, log_backup_count):
         """ set up some logging """
         global LOG_PATH, LOG, logging_initialized
 
@@ -143,8 +130,8 @@ class App(Component):
 
         LOG.addFilter(RedactingFilter())
 
-        file_handler = RotatingFileHandler(LOG_PATH, maxBytes=10000000,
-                                           backupCount=10)
+        file_handler = RotatingFileHandler(LOG_PATH, maxBytes=log_max_bytes,
+                                           backupCount=log_backup_count)
         file_handler.setFormatter(logging.Formatter(self.FILE_LOG_FORMAT))
         file_handler.addFilter(RedactingFilter())
         logging.getLogger().addHandler(file_handler)
