@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# (c) Copyright IBM Corp. 2010, 2021. All Rights Reserved.
+# (c) Copyright IBM Corp. 2010, 2023. All Rights Reserved.
 
 import logging
 import os
@@ -23,6 +23,8 @@ class AppArgumentParser(keyring_arguments.ArgumentParser):
     DEFAULT_COMPONENTS_DIR = ''
     DEFAULT_LOG_LEVEL = 'INFO'
     DEFAULT_LOG_FILE = 'app.log'
+    DEFAULT_LOG_MAX_BYTES = 10000000
+    DEFAULT_LOG_BACKUP_COUNT = 10
     DEFAULT_NO_PROMPT_PASS = "False"
     DEFAULT_STOMP_TIMEOUT = 60
     DEFAULT_STOMP_MAX_RETRIES = 3
@@ -30,6 +32,7 @@ class AppArgumentParser(keyring_arguments.ArgumentParser):
     DEFAULT_NUM_WORKERS = 25
     DEFAULT_APP_EXCEPTION = False
     DEFAULT_HEARTBEAT_TIMEOUT_THRESHOLD = None
+    DEFAULT_RC_USE_PERSISTENT_SESSIONS = True
 
     def __init__(self, config_file=None):
 
@@ -42,6 +45,8 @@ class AppArgumentParser(keyring_arguments.ArgumentParser):
         default_log_dir = self.getopt(self.DEFAULT_APP_SECTION, "logdir") or constants.APP_LOG_DIR
         default_log_level = self.getopt(self.DEFAULT_APP_SECTION, "loglevel") or self.DEFAULT_LOG_LEVEL
         default_log_file = self.getopt(self.DEFAULT_APP_SECTION, "logfile") or self.DEFAULT_LOG_FILE
+        default_log_max_bytes = self.getopt(self.DEFAULT_APP_SECTION, constants.APP_CONFIG_LOG_MAX_BYTES) or self.DEFAULT_LOG_MAX_BYTES
+        default_log_backup_count = self.getopt(self.DEFAULT_APP_SECTION, constants.APP_CONFIG_LOG_BACKUP_COUNT) or self.DEFAULT_LOG_BACKUP_COUNT
 
         # STOMP port is usually 65001
         default_stomp_port = self.getopt(self.DEFAULT_APP_SECTION, "stomp_port") or self.DEFAULT_STOMP_PORT
@@ -65,10 +70,16 @@ class AppArgumentParser(keyring_arguments.ArgumentParser):
                                             "log_http_responses") or ""
         default_resource_prefix = self.getopt(self.DEFAULT_APP_SECTION, "resource_prefix") or None
         default_num_workers = self.getopt(self.DEFAULT_APP_SECTION, "num_workers") or self.DEFAULT_NUM_WORKERS
+        default_stomp_prefetch_limit = int(self.getopt("resilient", "stomp_prefetch_limit") or default_num_workers)
         default_trap_exception = self.getopt(self.DEFAULT_APP_SECTION, constants.APP_CONFIG_TRAP_EXCEPTION) or self.DEFAULT_APP_EXCEPTION
         default_trap_exception = self._is_true(default_trap_exception)
 
         default_heartbeat_timeout_threshold = self.getopt(self.DEFAULT_APP_SECTION, constants.APP_CONFIG_HEARTBEAT_TIMEOUT_THRESHOLD) or self.DEFAULT_HEARTBEAT_TIMEOUT_THRESHOLD
+        default_rc_use_persistent_sessions = self.getopt(self.DEFAULT_APP_SECTION, constants.APP_CONFIG_RC_USE_PERSISTENT_SESSIONS) or self.DEFAULT_RC_USE_PERSISTENT_SESSIONS
+
+        default_selftest_timeout = self.getopt(self.DEFAULT_APP_SECTION, constants.APP_CONFIG_SELFTEST_TIMEOUT) or constants.DEFAULT_SELFTEST_TIMEOUT_VALUE
+
+        default_low_code_queues = self.getopt(self.DEFAULT_APP_SECTION, constants.LOW_CODE_QUEUES_LIST_APP_CONFIG) or None
 
         self._unset_temp_logger()
 
@@ -119,12 +130,20 @@ class AppArgumentParser(keyring_arguments.ArgumentParser):
                           help="Directory for log files")
         self.add_argument("--loglevel",
                           type=str,
-                          default=default_log_level,
+                          default=os.environ.get("LOGLEVEL", default_log_level),
                           help="Log level")
         self.add_argument("--logfile",
                           type=str,
                           default=default_log_file,
                           help="File to log to")
+        self.add_argument("--{0}".format(constants.APP_CONFIG_LOG_MAX_BYTES),
+                          type=int,
+                          default=default_log_max_bytes,
+                          help="Maximum bytes per log file")
+        self.add_argument("--{0}".format(constants.APP_CONFIG_LOG_BACKUP_COUNT),
+                          type=int,
+                          default=default_log_backup_count,
+                          help="Number of log files to create in rotation")
         self.add_argument("--no-prompt-password",
                           type=bool,
                           default=default_no_prompt_password,
@@ -155,6 +174,10 @@ class AppArgumentParser(keyring_arguments.ArgumentParser):
                           default=default_num_workers,
                           help=("Number of FunctionWorkers to use. "
                                 "Number of Functions that can run in parallel"))
+        self.add_argument("--stomp-prefetch-limit",
+                          default=default_stomp_prefetch_limit,
+                          type=int,
+                          help="MAX number of Action Module messages to send before ACK is required")
         self.add_argument("--trap-exception",
                           type=bool,
                           default=default_trap_exception,
@@ -163,6 +186,17 @@ class AppArgumentParser(keyring_arguments.ArgumentParser):
                           type=int,
                           default=default_heartbeat_timeout_threshold,
                           help=("The amount of time in seconds that can occur between HeartbeatTimeouts before exiting"))
+        self.add_argument("--{0}".format(constants.APP_CONFIG_RC_USE_PERSISTENT_SESSIONS),
+                          type=str,
+                          default=default_rc_use_persistent_sessions,
+                          help=("Set to False to disable the use of persistent sessions with RequestsCommon in app functions"))
+        self.add_argument("--{0}".format(constants.APP_CONFIG_SELFTEST_TIMEOUT),
+                          type=int,
+                          default=default_selftest_timeout,
+                          help=("Selftest timeout. Defaults to {0}".format(default_selftest_timeout)))
+        self.add_argument("--{0}".format(constants.LOW_CODE_QUEUES_LIST_APP_CONFIG),
+                          type=str,
+                          default=default_low_code_queues)
 
     def parse_args(self, args=None, namespace=None, ALLOW_UNRECOGNIZED=False):
         """Parse commandline arguments and construct an opts dictionary"""
@@ -173,7 +207,7 @@ class AppArgumentParser(keyring_arguments.ArgumentParser):
                 items = dict((item.lower(), self.config.get(section, item)) for item in self.config.options(section))
                 opts.update({section: items})
 
-            parse_parameters(opts)
+            opts = parse_parameters(opts)
 
             # Once we have read the app.config and decrypted any protected secrets
             # we must remove the secrets directory
