@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# (c) Copyright IBM Corp. 2010, 2018. All Rights Reserved.
+# (c) Copyright IBM Corp. 2010, 2025. All Rights Reserved.
+# pragma pylint: disable=line-too-long, wrong-import-order
 
 """ Command line tool to manage and run resilient-circuits """
 import argparse
@@ -8,9 +9,11 @@ import logging
 import os
 import sys
 from collections import defaultdict
-import pkg_resources
+from importlib.metadata import distributions
+from importlib.resources import files
 from resilient import get_config_file
 from resilient_circuits import helpers, constants
+from resilient_circuits.helpers import get_distribution_from_entry_point, get_distribution_name, get_entry_points as iter_entry_points
 from resilient_circuits.util.resilient_customize import customize_resilient
 from resilient_circuits.cmds import selftest
 
@@ -80,7 +83,7 @@ def run(resilient_circuits_args, restartable=False, config_file=None):
     if config_file:
         kwargs = {"config_file": config_file}
 
-    LOG.info(helpers.get_env_str(pkg_resources.working_set))
+    LOG.info(helpers.get_env_str(distributions()))
 
     app.run(**kwargs)
 
@@ -94,63 +97,77 @@ def list_installed(args):
     # - resilient.circuits.customize: produces schema customizations
     # - resilient.circuits.components: identifies components that implement actions, functions, etc.
     # We want to list all components, but include (as "empty") packages that define the other entry-points too.
+
+    # all installed
+    installed_packages = {get_distribution_name(dist): dist for dist in distributions()}
+
     entry_points = []
-    entry_points.extend([ep for ep in pkg_resources.iter_entry_points('resilient.circuits.config')])
-    entry_points.extend([ep for ep in pkg_resources.iter_entry_points('resilient.circuits.customize')])
-    component_entry_points = [ep for ep in pkg_resources.iter_entry_points('resilient.circuits.components')]
+    entry_points.extend(list(helpers.get_entry_points("resilient.circuits.config")))
+    entry_points.extend(list(helpers.get_entry_points("resilient.circuits.customize")))
+    component_entry_points = list(helpers.get_entry_points("resilient.circuits.components"))
     entry_points.extend(component_entry_points)
     LOG.debug(u"Found %d installed entry-points", len(entry_points))
     for ep in entry_points:
-        components[ep.dist].append(ep)
+        components[helpers.get_entry_point_name(ep)].append(ep)
     if not components:
         LOG.info(u"No resilient-circuits components are installed")
         return
 
     ep_list = {}
     LOG.info(u"The following packages and components are installed:")
-    for dist, component_list in components.items():
+    for pkg_name, component_list in components.items():
         if args.verbose:
-            clist = "\n\t".join([str(ep) for ep in component_list if ep in component_entry_points])
+            clist = "\n\t".join([f"{ep.name} = {ep.value}" for ep in component_list if ep in component_entry_points])
             if clist == "":
-                ep = u"{} ({}):\n\t(Package does not define any components)".format(
-                    dist.as_requirement(),
-                    dist.egg_info)
+                ep_info = u"{} ({}):\n\t(Package does not define any components)".format(
+                    as_requirement(installed_packages.get(pkg_name)),
+                    egg_info(installed_packages.get(pkg_name)))
             else:
-                ep = u"{} ({}):\n\t{}".format(
-                    dist.as_requirement(),
-                    dist.egg_info,
+                ep_info = u"{} ({}):\n\t{}".format(
+                    as_requirement(installed_packages.get(pkg_name)),
+                    egg_info(installed_packages.get(pkg_name)),
                     clist)
         else:
             clist = "\n\t".join([ep.name for ep in component_list if ep in component_entry_points])
             if clist == "":
-                ep = u"{}:\n\t(Package does not define any components)".format(
-                    dist.as_requirement())
+                ep_info = u"{}:\n\t(Package does not define any components)".format(
+                    as_requirement(installed_packages.get(pkg_name)))
             else:
-                ep = u"{}:\n\t{}".format(
-                    dist.as_requirement(),
+                ep_info = u"{}:\n\t{}".format(
+                    as_requirement(installed_packages.get(pkg_name)),
                     clist)
 
-        ep_list[str(dist.as_requirement())] = ep
+        ep_list[str(as_requirement(installed_packages.get(pkg_name)))] = ep_info
 
     for ep_item in sorted(ep_list.keys()):
         LOG.info(ep_list[ep_item])
 
+def as_requirement(dist):
+    ### this function recreates the results returns from pkg_resource.EntryPoint.as_requirement()
+    if dist:
+        return f"{get_distribution_name(dist)}=={dist.version}"
+    else:
+        return "Unknown"
+
+def egg_info(dist):
+    ### this function recreates the results returns from pkg_resource.EntryPoint.as_requirement()
+    return str(dist._path)
 
 def generate_default(install_list):
     """ return string containing entire default app.config """
-    base_config_fn = pkg_resources.resource_filename("resilient_circuits", "data/app.config.base")
-    entry_points = pkg_resources.iter_entry_points('resilient.circuits.configsection')
+    base_config_fn = files("resilient_circuits").joinpath("data", "app.config.base")
+    entry_points = helpers.get_entry_points("resilient.circuits.configsection")
     additional_sections = []
     remaining_list = install_list[:] if install_list else []
     for entry in entry_points:
-        dist = entry.dist
-        package_name = entry.dist.project_name
+        dist = get_distribution_from_entry_point(entry)
+        package_name = get_distribution_name(dist)
 
         # if a list is provided, use it to filter which packages to add to the app.config file
         if install_list is not None and package_name not in remaining_list:
             LOG.debug("{} bypassed".format(package_name))
             continue
-        elif package_name in remaining_list:
+        if package_name in remaining_list:
             remaining_list.remove(package_name)
 
         try:
@@ -228,13 +245,13 @@ def generate_or_update_config(args):
             config.read_file(config_file)
             existing_sections = config.sections()
 
-        entry_points = pkg_resources.iter_entry_points('resilient.circuits.configsection')
+        entry_points = iter_entry_points(group='resilient.circuits.configsection')
         remaining_list = args.install_list[:] if args.install_list else []
 
         with open(config_filename, "a", encoding="utf-8") as config_file:
             for entry in entry_points:
-                dist = entry.dist
-                package_name = entry.dist.project_name
+                dist = get_distribution_from_entry_point(entry)
+                package_name = get_distribution_name(dist)
                 try:
                     func = entry.load()
                 except ImportError:
@@ -257,7 +274,7 @@ def generate_or_update_config(args):
                 if new_section and new_section not in existing_sections:
                     if args.install_list is None or package_name in remaining_list:
                         # Add the default data for this required section to the config file
-                        LOG.info(u"Adding new section '%s' for '%s'", new_section, dist)
+                        LOG.info(u"Adding new section '%s' for '%s'", new_section, package_name)
                         if package_name in remaining_list:
                             remaining_list.remove(package_name)
 
@@ -285,7 +302,7 @@ def main():
     parser = argparse.ArgumentParser(
         prog="resilient-circuits",
         description="Runtime environment for apps used with IBM Security SOAR",
-        epilog="For support, please visit ibm.biz/soarcommunity"
+        epilog="For support, please visit https://ibm.biz/soarcommunity"
     )
 
     parser.usage = """
