@@ -3,21 +3,26 @@
 
 """Circuits component for Action Module subscription and message handling"""
 
+import inspect as _inspect
 import logging
 import threading
 from collections import namedtuple
-import inspect as _inspect
 from functools import wraps
 from types import GeneratorType
-from circuits import Timer, task, Event
+
 import circuits.core.handlers
-from resilient_lib import ResultPayload, validate_fields
-from resilient_circuits import constants
-from resilient_circuits.action_message import FunctionResult, \
-    StatusMessage, StatusMessageEvent, \
-    FunctionError_, FunctionErrorEvent
+from circuits import Event, Timer, task
+from resilient_circuits import constants, helpers
+from resilient_circuits.action_message import (FunctionError_,
+                                               FunctionErrorEvent,
+                                               FunctionResult, LowCodeResult,
+                                               StatusMessage,
+                                               StatusMessageEvent)
+from resilient_circuits.filters import RedactingFilter
+from resilient_lib import LowCodePayload, ResultPayload, validate_fields
 
 LOG = logging.getLogger(__name__)
+LOG.addFilter(RedactingFilter())
 
 # for convenience we alias the circuits 'handler'
 handler = circuits.core.handlers.handler
@@ -51,8 +56,8 @@ class function(object):
         func.priority = self.kwargs.get("priority", 0)
         func.channel = self.kwargs.get("channel", ",".join(["functions.{}".format(name) for name in self.names]))
         func.override = self.kwargs.get("override", False)
-        
-        # If getfullargspec if available to us 
+
+        # If getfullargspec if available to us
         if hasattr(_inspect, 'getfullargspec'):
             args = _inspect.getfullargspec(func)[0]
         else:  # fall back to deprecated getargspec
@@ -73,7 +78,7 @@ class function(object):
 
             def _call_the_task(evt, **kwds):
                 # On the worker thread, call the function, and handle a single or generator result.
-                LOG.debug("%s: _call_the_task", threading.currentThread().name)
+                LOG.debug("%s: _call_the_task", threading.current_thread().name)
                 result_list = []
                 task_result_or_gen = _the_task(evt, *args, **kwds)
                 if not isinstance(task_result_or_gen, GeneratorType):
@@ -160,18 +165,37 @@ class inbound_app(object):
                     -  E.g:
                         `yield "Processing Complete!"`
 
+                The method that is wrapped with this handler should will receive three items:
+                    - message
+                    - headers
+                    - inbound action
+
+                The subclass of ``ResilientComponent`` is also required to set the
+                ``app_configs`` attribute.
+
+                Example:
+
+                .. code-block:: python
+
+                    class SoarInboundConsumer(ResilientComponent):
+                        def __init__(self, opts):
+                            super(SoarInboundConsumer, self).__init__(opts)
+                            self.opts = opts
+                            self.app_configs = opts.get(PACKAGE_NAME, {})
+
+                        @inbound_app(QUEUE_NAME)
+                        def _inbound_soar_escalator(self, message, headers, inbound_action):
+                            pass
+
                 :param evt: The Event with the StompFrame and the Message read off the Message Destination
                 :type ia: resilient_circuits.action_message.FunctionMessage
                 """
                 result_list = []
-                LOG.debug("Running _invoke_inbound_app in Thread: %s", threading.currentThread().name)
-
-                # Get the required attribute from the message
-                message = evt.message
-                inbound_action = message.get("action", "Unknown")
+                LOG.debug("Running _invoke_inbound_app in Thread: %s", threading.current_thread().name)
 
                 # Invoke the actual Function
-                ia_results = ia(itself, evt.message, inbound_action)
+                # Pass along the message, the headers, and the action if present in the message
+                ia_results = ia(itself, evt.message, evt.headers, evt.message.get("action", "Unknown"))
 
                 for r in ia_results:
                     LOG.debug(r)
@@ -252,7 +276,7 @@ class app_function(object):
                 :param evt: The Event with the StompFrame and the Message read off the Message Destination
                 :type fn: resilient_circuits.action_message.FunctionMessage
                 """
-                LOG.debug("Running _invoke_app_function in Thread: %s", threading.currentThread().name)
+                LOG.debug("Running _invoke_app_function in Thread: %s", threading.current_thread().name)
 
                 result_list = []
 
@@ -263,6 +287,12 @@ class app_function(object):
 
                 rp = ResultPayload(itself.PACKAGE_NAME, version=constants.APP_FUNCTION_PAYLOAD_VERSION, **fn_inputs)
 
+                # make sure to sub AFTER the ResultPayload is instantiated so that any subbed values
+                # won't be logged or included in the returned inputs.
+                # substitute any secrets denoted with $, ^, ${}, or ^{} in the function inputs.
+                # NOTE: it is crucial to first "validate_fields" as that function will convert any
+                # non-string fields that should be strings to strings (like select)
+                fn_inputs = helpers.sub_fn_inputs_from_protected_secrets(fn_inputs, itself.opts)
                 fn_inputs_tuple = namedtuple("fn_inputs", fn_inputs.keys())(*fn_inputs.values())
 
                 # Set evt.message in local thread storage
@@ -303,6 +333,128 @@ class app_function(object):
         return app_function_decorator
 
 
+class low_code_function(object):
+    """
+    Decorator for the low code framework when running through app host.
+    The decorator takes optional low-code queues as arguments, however,
+    generally those queue names are defined in the app.config and loaded
+    in dynamically at component binding time (in component_loader.py).
+
+    NOTE: results from a ``low_code_function`` function can either be of type
+    ``FunctionResult`` or ``LowCodeResult``. The eventual result will be cast to a
+    ``LowCodeResult`` before being built to a ``LowCodePayload`` object
+    and returned to the queue in SOAR.
+
+    Example use:
+
+    .. code-block::
+
+        class FunctionComponent(AppFunctionComponent):
+
+            def __init__(self, opts):
+                super(FunctionComponent, self).__init__(opts, PACKAGE_NAME)
+
+            @low_code_function()
+            def _run_low_code(self, fn_inputs):
+                yield self.status_message("Low Code execution started")
+                ...
+                yield FunctionResult({"results": "value"})
+
+    :param object: _description_
+    :type object: _type_
+    """
+
+    def __init__(self, *args, **kwargs):
+        self.args = args
+        self.kwargs = kwargs
+
+        # because this has to be set dynamically based on app.config values,
+        # names is set in component loader
+        self.names = args
+
+    def __call__(self, fn):
+        """
+        Called at decoration time, with the bare function being decorated
+
+        :param fn: The function to decorate
+        :type fn: resilient_circuits.ResilientComponent
+        """
+        fn.handler = True
+        fn.low_code_handler = True
+
+
+        # Circuits properties
+        fn.names = self.names
+        fn.priority = self.kwargs.get("priority", 0)
+        fn.channel = constants.LOW_CODE_MSG_DEST_PREFIX
+        fn.override = self.kwargs.get("override", False)
+        fn.event = True
+
+        @wraps(fn)
+        def low_code_decorator(itself, event, *args, **kwargs):
+            low_code_message = event.message    # {"request_originator": {}, "request_payload": {}}
+            invoke_low_code_function = task(_invoke_low_code_function, event, itself, fn, **low_code_message)
+            fn_result = yield itself.call(invoke_low_code_function, "functionworker")
+            yield fn_result.value
+
+        return low_code_decorator
+
+def _invoke_low_code_function(event, app_fn_component_obj, the_function, **kwds):
+    LOG.debug("Running _invoke_low_code_function in Thread: %s", threading.current_thread().name)
+
+    result_list = []
+
+    # Validate the fn_inputs in the Message
+    connector_inputs = validate_fields(["request_originator","request_payload"], kwds)
+    LOG.info("[%s] Validated connector inputs", event.name)
+    LOG.debug("[%s] connector_inputs: %s", event.name, connector_inputs)
+
+    lc_payload = LowCodePayload(app_fn_component_obj.PACKAGE_NAME, version=constants.LOW_CODE_PAYLOAD_VERSION, **connector_inputs)
+
+    connector_inputs = helpers.sub_fn_inputs_from_protected_secrets(connector_inputs, app_fn_component_obj.opts)
+
+    # Set evt.message in local thread storage
+    app_fn_component_obj.set_fn_msg(event.message)
+
+    # Pull out the request_payload, this is all we need to execute the request
+    low_code_request = connector_inputs.get("request_payload")
+
+    # Invoke the actual Function
+    fn_results = the_function(app_fn_component_obj, low_code_request)
+
+    for result in fn_results:
+        # if a FunctionResult comes through, convert it to a LowCodeResult
+        # first before continuing with the rest of the result processing
+        if isinstance(result, FunctionResult):
+            result = LowCodeResult.from_function_result(result)
+
+        # handle the result as necessary; send status message, or ack result
+        if isinstance(result, StatusMessage):
+            LOG.info("[%s] StatusMessage: %s", event.name, result)
+            app_fn_component_obj.fire(StatusMessageEvent(parent=event, message=result.text))
+
+        elif isinstance(result, LowCodeResult):
+            result.name = event.name
+            if not result.custom_results:
+                result.value = lc_payload.done(
+                    content=result.value.get("content"),
+                    success=result.success,
+                    reason=result.reason,
+                    content_type=low_code_request.get("response_content_type", None),
+                    status_code=result.value.get("status_code"))
+            LOG.info("[%s] Returning results", result.name)
+            result_list.append(result)
+
+        elif isinstance(result, Exception):
+            raise result
+
+        else:
+            # Whatever this is, add it to the results
+            LOG.debug(result)
+            result_list.append(result)
+
+    return result_list
+
 class required_field(object):
     """Decorator, declares a required field for a ResilientComponent or its methods"""
     def __init__(self, fieldname, input_type=None):
