@@ -1,19 +1,25 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# (c) Copyright IBM Corp. 2010, 2020. All Rights Reserved.
+# (c) Copyright IBM Corp. 2010, 2025. All Rights Reserved.
+# pragma pylint: disable=line-too-long, wrong-import-order
 
 """Common Helper Functions for resilient-circuits"""
-import sys
-import pkg_resources
-import logging
 import copy
+import logging
 import re
+import sys
 import time
-from resilient_circuits import constants
-from resilient import get_client
-from resilient import is_env_proxies_set, get_and_parse_proxy_env_var
-from resilient import constants as res_constants
 
+from collections.abc import Iterable
+from importlib.metadata import entry_points, distribution
+from importlib.util import find_spec, module_from_spec
+from resilient_circuits import constants
+from six import string_types
+
+from resilient import constants as res_constants
+from resilient import (get_and_parse_proxy_env_var, get_client,
+                       is_env_proxies_set)
+from resilient.app_config import AppConfigManager
 
 LOG = logging.getLogger("__name__")
 
@@ -79,6 +85,7 @@ def get_handlers(component, handler_type="inbound_handler"):
 
     for m in methods:
         this_method = getattr(component, m)
+        # for low_code, the decorator sets the 'low_code_handler' attribute
         is_handler = getattr(this_method, handler_type, False)
 
         if is_handler:
@@ -116,11 +123,12 @@ def get_configs(path_config_file=None, ALLOW_UNRECOGNIZED=False):
     :param ALLOW_UNRECOGNIZED: bool to specify if AppArgumentParser will allow unknown comandline args or not. Default is False
     :type ALLOW_UNRECOGNIZED: bool
     :return: dictionary of all the configs in the app.config file
-    :rtype: dict
+    :rtype: ``resilient.app_config.AppConfigManager``
     """
-    from resilient import get_config_file
     from resilient_circuits.app_argument_parser import AppArgumentParser
 
+    from resilient import get_config_file
+
     if not path_config_file:
         path_config_file = get_config_file()
 
@@ -128,19 +136,32 @@ def get_configs(path_config_file=None, ALLOW_UNRECOGNIZED=False):
     return configs
 
 
-def get_resilient_client(path_config_file=None, ALLOW_UNRECOGNIZED=False):
+def get_resilient_client_for_selftest(path_config_file=None, ALLOW_UNRECOGNIZED=False, default_connection_retries=3):
     """
     Return a SimpleClient for Resilient REST API using configurations
-    options from provided path_config_file or from ~/.resilient/app.config
+    options from provided path_config_file or from ~/.resilient/app.config.
+
+    This method is only intended for use in selftest. For other use cases, use
+    ``from resilient_circuits.rest_helper import get_resilient_client``
 
     :param path_config_file: path to the app.config to parse
     :type path_config_file: str
     :param ALLOW_UNRECOGNIZED: bool to specify if AppArgumentParser will allow unknown comandline args or not. Default is False
     :type ALLOW_UNRECOGNIZED: bool
+    :param default_connection_retries: used for selftest limiting the number of retries when connecting. Default is 3 tries
+    :type default_connection_retries: int
     :return: SimpleClient for Resilient REST API
     :rtype: SimpleClient
     """
-    client = get_client(get_configs(path_config_file=path_config_file, ALLOW_UNRECOGNIZED=ALLOW_UNRECOGNIZED))
+
+    # if default_connection_retries is provided or default
+    if default_connection_retries is not None:
+        # add retry configs
+        kwargs = {res_constants.APP_CONFIG_MAX_CONNECTION_RETRIES: default_connection_retries}
+    else:
+        kwargs = {}
+
+    client = get_client(get_configs(path_config_file=path_config_file, ALLOW_UNRECOGNIZED=ALLOW_UNRECOGNIZED), **kwargs)
     return client
 
 
@@ -197,19 +218,20 @@ def get_packages(working_set):
     and their version in working_set
 
     :param working_set: the working_set for all packages installed in this env
-    :type working_set: setuptools.pkg_resources.WorkingSet obj
+    :type working_set: importlib.metadata.Distribution obj
     :return: pkg_list: a list of tuples [('name','version')] e.g. [('resilient-circuits', '39.0.0')].
-        If ``working_set`` is not a ``pkg_resources.WorkingSet`` object, just return the current value of ``working_set``
+        If ``working_set`` is not a ``importlib.metadata.Distribution`` object, just return the current value of ``working_set``
     :rtype: list
     """
 
-    if not isinstance(working_set, pkg_resources.WorkingSet):
+    if not isinstance(working_set, Iterable):
         return working_set
 
     pkg_list = []
 
     for pkg in working_set:
-        pkg_list.append((pkg.project_name, pkg.version))
+        if hasattr(pkg, "name"):
+            pkg_list.append((pkg.name, pkg.version))
 
     return sorted(pkg_list, key=lambda x: x[0].lower())
 
@@ -219,8 +241,8 @@ def get_env_str(packages):
     Return a str with the Python version and the
     packages
 
-    :param packages: the working_set for all packages installed in this env
-    :type packages: setuptools.pkg_resources.WorkingSet obj
+    :param packages: the distribution for all packages installed in this env
+    :type packages: importlib.metadata.PathDistribution obj
     :return: env_str: a str of the Environment
     :rtype: str
     """
@@ -244,9 +266,6 @@ def get_env_str(packages):
     env_str += u"\n###############"
     return env_str
 
-
-
-
 def get_queue(destination):
     """
     Return a tuple (queue_type, org_id, queue_name).
@@ -257,21 +276,27 @@ def get_queue(destination):
     :return: queue: (queue_type, org_id, queue_name) e.g. ('actions', '201', 'fn_main_mock_integration')
     :rtype: tuple
     """
+    destination_str = destination
 
     try:
-        assert isinstance(destination, str)
+        assert isinstance(destination_str, str)
 
+        # regex.sub to remove any /queue/ in the start
         regex = re.compile(r'\/.+\/')
+        destination_str = re.sub(regex, "", destination_str, count=1)
 
-        destination = re.sub(regex, "", destination, count=1)
-        q = destination.split(".")
+        # split on periods to get the type, org_id, and queue name
+        # use maxsplit=2 to only split on the first two periods,
+        # as the third item might be a queue_name with a period in it
+        # note in PY2 maxsplit is a positional arg so we don't label it here for compatibility
+        q = destination_str.split(".", 2)
 
         assert len(q) == 3
 
         return (tuple(q))
 
     except AssertionError as e:
-        LOG.error("Could not get queue name\n%s", str(e))
+        LOG.error("Could not get queue name from destination: '%s'\n%s", destination, str(e))
         return None
 
 
@@ -348,3 +373,164 @@ def filter_heartbeat_timeout_events(heartbeat_timeouts):
     heartbeat_timeouts.sort()
 
     return heartbeat_timeouts
+
+def sub_fn_inputs_from_protected_secrets(fn_inputs, opts):
+    """
+    Substitute any protected secret *or regular secret
+    into a function input. Requires the ``opts`` dictionary
+    (usually actually a AppConfigManager object) to be
+    given to properly create a temporary AppConfigManager
+    that will have access to the pam plugin if relevant.
+
+    This supports the same syntax as secrets in app.config:
+      - if $ or ^ starts a string, if the following string
+        is found in secrets, it will be replaced
+      - if ${} or ^{} is found within a string, the value
+        there will be replaced with the appropriate secret
+        if found
+    In either case, if the value following the reserved character
+    is not found in secrets, the original value will remain and no
+    substitution will be made.
+
+    **Example:**
+
+    .. code-block::python
+
+        fn_inputs = {"fn_my_app_input_1": "Sub in ${HERE}"}
+        fn_inputs = helpers.sub_fn_inputs_from_protected_secrets(fn_inputs, opts)
+        assert fn_inputs["fn_my_app_input_1"] == "Sub in <value from secrets>"
+
+    :param fn_inputs: function inputs as a dictionary (retrieved from the event message)
+    :type fn_inputs: dict
+    :param opts: app configs from AppFunctionComponent (usually self.opts)
+    :type opts: AppConfigManager | dict
+    :return: fn_inputs unchanged except where secrets referenced are replaced
+    :rtype: dict
+    """
+    fn_inputs = copy.deepcopy(fn_inputs)
+
+    # find the pam_plugin type if necessary
+    if isinstance(opts, AppConfigManager) and opts.pam_plugin:
+        pam_plugin = type(opts.pam_plugin)
+    else:
+        pam_plugin = None
+
+    # use a AppConfigManager temporarily to take advantage of its
+    # protected secrets and PAM secrets substitution capabilities
+    fn_inputs_manager = AppConfigManager(fn_inputs, pam_plugin)
+
+    # since the value for fn_inputs will quickly be translated
+    # to a namedtuple anyway, we simply set the values to the
+    # substituted values from the AppConfigManager here.
+    # This is different from how we'd use the AppConfigManager
+    # within the rest of the function code, where we'd usually
+    # persist the object so that values (especially PAM values)
+    # are guaranteed to be up to date. in this case, these values
+    # will be used relatively quickly within a function so we can
+    # statically save the found value here and we assume it will
+    # be used quickly enough in the function to be up to date.
+    # NOTE: some inputs might not be strings. in that case,
+    # they will not be substituted, they will remain their
+    # original value and structure. This applies to ints,
+    # multiselects, booleans, and date time pickers.
+    # All text, text with string, and select (single) inputs
+    # will attempt to substitute if applicable
+    for key in fn_inputs_manager:
+        if isinstance(fn_inputs[key], string_types):
+            fn_inputs[key] = fn_inputs_manager[key]
+
+    return fn_inputs
+
+def get_entry_points(group):
+    """get the importlib EntryPoint objects for a given group
+
+    :param group: group to search installed packages. Ex. resilient.circuits.selftest
+    :type group: str
+    :return: list of entrypoints found
+    :rtype: list
+    """
+    if sys.version_info.major == 3 and sys.version_info.minor > 9:
+        return entry_points(group=group)
+    else:
+        eps = entry_points()
+        return eps.get(group, [])
+
+def get_entry_point_name(ep):
+    """ find the name of the app from the importlib EntryPoint
+
+    :param ep: EntryPoint object 
+    :type ep: importlib EntryPoint 
+    :return: name of app
+    :rtype: str
+    """
+    return ep.value.split(".")[0] if ep else ""
+
+def get_entry_function(entry):
+    """get function associated with an entrypoint definition
+
+    :param entry: import.metadata.EntryPoint
+    :type entry: import.metadata.EntryPoint
+    :return: function associated with EnterPoint
+    :rtype: object
+    """
+    # ep.value like 'fn_outbound_email.util.config:config_section_data'
+    (spec_name, funct_name) = entry.value.split(":")
+    spec = find_spec(spec_name)
+
+    if spec:
+        module = module_from_spec(spec)
+
+        if module:
+            spec.loader.exec_module(module)
+            return getattr(module, funct_name, None)
+
+    return None
+
+def get_package_function(package, group):
+    """ return the entry point function for a install app.
+
+    :param package: name of the app. ex: fn_rest_api
+    :type package: str
+    :param group: entry point info. ex: resilient.circuits.selftest
+    :type group: str
+    :return: object
+    :rtype: function for the given package and group entry point
+    """
+    entries = get_entry_points(group=group)
+    for entry in entries:
+        if package == get_entry_point_name(entry):
+            return get_entry_function(entry)
+
+    return None
+
+def get_distribution_name(dist):
+    """find the name of the importlib.metadata.Distribution object
+        Python 3.9 is different than 3.12
+
+    :param dist: object to parse
+    :type dist: Distribution
+    :return: Name of distribution
+    :rtype: str
+    """
+    if not dist:
+        return None
+
+    if hasattr(dist, "name"):
+        return dist.name
+    else:
+        return dist.metadata["name"]
+
+def get_distribution_from_entry_point(ep):
+    """ get the distribution object from the entry point object
+        Python 3.9 is different than 3.12
+
+    :param ep: entrypoint
+    :type ep: EntryPoint
+    :return: associated distribution
+    :rtype: Distribution
+    """
+    if hasattr(ep, "dist"):
+        return ep.dist
+    else:
+        pkg_name = ep.value.split(".")[0]
+        return distribution(pkg_name)
