@@ -6,7 +6,7 @@
 Common place for helper functions used in tests
 """
 
-from resilient_circuits import SubmitTestInboundApp, SubmitTestFunction, FunctionResult
+from resilient_circuits import SubmitTestInboundApp, SubmitTestFunction, SubmitTestLowCodeApp, FunctionResult
 
 
 def call_app_function(fn_name, fn_inputs, circuits_app, status_message_only=False, full_result_obj=False):
@@ -62,3 +62,26 @@ def call_inbound_app(circuits_app, queue_name, action="create", msg_content={},
         return event.args
 
     return False
+
+def call_low_code_function(circuits_app, queue_name, message=None):
+    """Call Low code function here
+    """
+    evt = SubmitTestLowCodeApp(queue_name, message)
+
+    # Fire a message to the inbound app
+    circuits_app.manager.fire(evt)
+
+    # circuits will fire an "exception" event if an exception is raised in the ResilientComponent
+    # return this exception if it is raised
+    exception_event = circuits_app.watcher.wait("exception", parent=None, timeout=2)
+
+    if exception_event:
+        exception = exception_event.args[1]
+        raise exception
+
+    event = circuits_app.watcher.wait(queue_name + u"_success", parent=evt, timeout=2)
+
+    if event:
+        return event.args
+
+    return False
\ No newline at end of file
